@@ -42,26 +42,24 @@ class CenterIdentity:
         return base64.b64encode(signature).decode('utf-8')
 
     def do_challenge(self, body):
-        req = requests.post(f'{self.url_prefix}/challenge', json={
+        res = self.do_request('/challenge', {
             'api_key': self.identity['username_signature'],
             'identity': self.identity
         })
-        challenge_context = req.json()['challenge']
+        challenge_context = res['challenge']
         signature = self.sign(challenge_context['challenge']['message'])
         challenge_context['challenge']['signature'] = signature
         challenge_context['client_identity'] = body['identity']
         return challenge_context
 
     def verify_client_challenge(self, challenge_context):
-        req = requests.post(f'{self.url_prefix}/challenge', json=challenge_context)
-        return req.json()
+        return self.do_request('/challenge', challenge_context)
 
     def get_recovery(self, body):
         challenge_result = self.verify_client_challenge(body)
         if challenge_result['status'] is True:
             challenge_context = self.do_challenge(body)
-            res = requests.post(f'{self.url_prefix}/get-recovery', json=challenge_context)
-            return res.json()
+            return self.do_request('/get-recovery', challenge_context)
         return {'status': False}
 
     def set_recovery(self, client_username, body):
@@ -71,5 +69,8 @@ class CenterIdentity:
         if client_username != body['identity']['username']:
             return {'status': False}
         challenge_context = self.do_challenge(body)
-        res = requests.post(f'{self.url_prefix}/set-recovery', json=challenge_context)
-        return res.json()
\ No newline at end of file
+        return self.do_request('/set-recovery', challenge_context)
+
+    def do_request(self, url, data):
+        res = requests.post(f'{self.url_prefix}{url}', json=data)
+        return res.json()
